@@ -38,11 +38,12 @@ IGNORED_SYMBOLS = [
 # Rust
 IGNORED_SYMBOLS += [
     "rust_eh_personality",
-    "_ZN3std9panicking11EMPTY_PANIC.*",  # 'std::panicking::EMPTY_PANIC::.*'
-    "_ZN3std3sys3pal4unix4args3imp15ARGV_INIT_ARRAY.*",  # 'std::sys::pal::unix::args::imp::ARGV_INIT_ARRAY::.*'
-    "_ZN3std3sys4args4unix3imp15ARGV_INIT_ARRAY.*",  # std::sys::args::unix::imp::ARGV_INIT_ARRAY::.*
-    "_ZN17compiler_builtins.*",  # 'compiler_builtins::.*'
-    '_hb_harfruzz_.*_rs',
+    "_.*3std9panicking11EMPTY_PANIC.*",  # 'std.*::panicking::EMPTY_PANIC::.*'
+    "_.*3std3sys3pal4unix4args3imp15ARGV_INIT_ARRAY.*",  # 'std.*::sys::pal::unix::args::imp::ARGV_INIT_ARRAY::.*'
+    "_.*3std3sys4args4unix3imp15ARGV_INIT_ARRAY.*",  # std.*::sys::args::unix::imp::ARGV_INIT_ARRAY::.*
+    "_.*17compiler_builtins.*",  # 'compiler_builtins.*::.*'
+    ".*__rustc.*",  # '.*__rustc.*' # Eg. _RNvCsgSLETaxrkfn_7___rustc17___rust_probestack
+    '_hb_harfrust_.*_rs',
 ]
 
 IGNORED_SYMBOLS = "|".join(IGNORED_SYMBOLS)
